==> haskell-wai-3.2.2.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.2.1
id: wai-3.2.2.1-7G70zI5dy01FNHM6AAlnXL
key: wai-3.2.2.1-7G70zI5dy01FNHM6AAlnXL
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
abi: 850ebc1612d51737936b4d5d24ef8568
exposed: True
exposed-modules:
    Network.Wai Network.Wai.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-3.2.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-3.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-3.2.2.1
hs-libraries: HSwai-3.2.2.1-7G70zI5dy01FNHM6AAlnXL
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    http-types-0.12.3-Coz39hkYXV9BhDskHfFaoY
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.3-JZ0YCyq9z4kGqiaSc3dflW
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.2
id: wai-3.2.2-BtHgtjjj622AnktyOudXpm
key: wai-3.2.2-BtHgtjjj622AnktyOudXpm
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
abi: 19a481a5495da1e3a71c5dad21e35660
exposed: True
exposed-modules:
    Network.Wai Network.Wai.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/wai-3.2.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/wai-3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wai-3.2.2
hs-libraries: HSwai-3.2.2-BtHgtjjj622AnktyOudXpm
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    http-types-0.12.2-7fBt47xPGhl6u7jd2P941Z
    network-2.8.0.0-2IPXD2Y68aq74YznYSHES6 text-1.2.3.1
    transformers-0.5.5.0 vault-0.3.1.2-4YnHXxdrk48D2KnMMRt9j6
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
